<?php
class CommentReportButtonPublic extends CommentReportButton {
	public function __construct() {
		parent::__construct();
		// ajaxアクション定義
		add_action( 'wp_ajax_report', array( $this, 'report' ) );
		add_action( 'wp_ajax_nopriv_report', array( $this, 'report' ) );
	}

	///////////////////////////////////////
	/* 初期定義 */
	///////////////////////////////////////
	public function init() {
		global $comment_report_option;

		// CSS&JavaScript定義
		add_action( 'wp_enqueue_scripts', array( $this, 'add_scripts' ) );

		// 通報数リセット
		add_action( 'wp_set_comment_status', array( $this, 'report_count_reset' ), 10, 2 );
		// add_action( 'wp_delete_comment', array( $this, 'report_count_reset' ) );

		// ボタン表示位置
		$comment_report_option = get_option( 'comment_report_option' );
		switch ( $comment_report_option['button_view_position'] ) {
			case 'auther':
				add_filter( 'get_comment_author', array( $this, 'view_report_button' ) );
				break;
			case 'date':
				add_filter( 'get_comment_date', array( $this, 'view_report_button' ) );
				break;
			case 'time':
				add_filter( 'get_comment_time', array( $this, 'view_report_button' ) );
				break;
			case 'text':
				add_filter( 'get_comment_text', array( $this, 'view_report_button' ) );
				break;
			case 'edit':
				add_filter( 'edit_comment_link', array( $this, 'view_report_button' ) );
				break;
			case 'reply':
				add_filter( 'comment_reply_link_args', array( $this, 'view_report_button_2' ) );
				break;
			default:
				break;
		}
	}

	///////////////////////////////////////
	/* 通報数リセット */
	///////////////////////////////////////
	public function report_count_reset( $comment_id, $status = '' ) {
		if ($status === 'approve') {
			delete_comment_meta( $comment_id, 'report_count' );
		}
	}

	///////////////////////////////////////
	/* 通報ボタン表示 */
	///////////////////////////////////////
	public function view_report_button( $str ) {
		global $comment_report_option;

		$btn = comment_report_button(false);

		if ($comment_report_option['button_view_position_baf'] == 'before') {
			$str = $btn. $str;
		} else {
			$str = $str. $btn;
		}

		return $str;
	}
	public function view_report_button_2( $args ) {
		global $comment_report_option;

		$btn = comment_report_button(false);

		if ($comment_report_option['button_view_position_baf'] == 'before') {
			$args['before'] = $btn. $args['before'];
		} else {
			$args['after'] = $args['after']. $btn;
		}

		return $args;
	}

	///////////////////////////////////////
	/* CSS&JavaScript定義 */
	///////////////////////////////////////
	public function add_scripts() {
		$data = get_file_data( COMMENT_REPORT_PLUGIN, array( 'version' => 'Version' ) );
		wp_enqueue_script( 'jquery' );
		wp_enqueue_script( 'commentReportButton', COMMENT_REPORT_PLUGIN_URL. '/js/jquery.script.js', array('jquery'), $data['version'], false );
		wp_localize_script(
			'commentReportButton',
			'_commentReportButton',
			array(
				'ajax_url' => admin_url( 'admin-ajax.php' ),
				'ajax_nonce_report' => wp_create_nonce( '_comment_report_button' ),
			)
		);
	}

	///////////////////////////////////////
	/* 通報処理 */
	///////////////////////////////////////
	public function report() {
		global $comment_report_option;

		$comment_id = ( isset( $_POST['comment_id'] ) ? $_POST['comment_id'] : 0 );

		// nonceチェック
		check_ajax_referer( '_comment_report_button', false, true );

		$comment = get_comment( $comment_id, ARRAY_A );
		$usip = getenv( 'REMOTE_ADDR' );

		if ( !empty( $comment ) && !empty($usip) ) {
			// 通報数取得
			$reports = get_comment_meta( $comment_id, 'reports', true );
			if ( empty($reports) ) $reports = array();

			if ( !in_array( $usip, $reports ) ) {
				// 通報数更新
				$reports[] = $usip;
				update_comment_meta( $comment_id, 'reports', $reports );
				$report_count = count($reports);

				// 一定数を超えれば状態変更
				if ( $comment_report_option['auto_unauthorized'] == 1 && $report_count > $comment_report_option['auto_unauthorized_count'] ) {
					wp_update_comment( array(
						'comment_ID' => $comment_id,
						'comment_approved' => 0
					) );
				}

				// 一定数を超えれば削除
				if ( $comment_report_option['auto_trash'] == 1 && $report_count > $comment_report_option['auto_trash_count'] ) {
					wp_delete_comment( $comment_id );
				}

				// 一定数に達したらメール通知
				if ( $comment_report_option['sendmail'] == 1 && !empty( $comment_report_option['sendmail_address'] ) && $report_count == $comment_report_option['sendmail_count'] ) {
					$this->sendmail( $comment_report_option['sendmail_address'], $comment );
				}

				// 正常完了
				status_header( '200' );
				echo 'OK';
			} else {
				// 既存通報
				status_header( '200' );
				echo 'Existing';
			}
		} else {
			// 異常終了
			status_header( '403' );
			echo 'Forbidden';
		}
		wp_die();
	}

	///////////////////////////////////////
	/* メール送信 */
	///////////////////////////////////////
	private function sendmail( $to, $comment ) {
		$subject = 'コメント通報通知';
		$body = "下記のコメントが通報されました。\n".
							"--------------------------------------------------------\n".
							"【名前】". $comment['comment_author']. "\n".
							"【コメント】". $comment['comment_content']. "\n".
							"【投稿日】". $comment['comment_date']. "\n".
							"--------------------------------------------------------\n".
							"コメントURL：". get_comment_link( $comment['comment_ID'] ). "\n";
		wp_mail( $to, $subject, $body );
	}
}
