<?php
new CommentReportSetting();

class CommentReportSetting {

	private $options;

	///////////////////////////////////////
	/* 初期定義 */
	///////////////////////////////////////
	public function __construct() {
		$plugin = plugin_basename( COMMENT_REPORT_PLUGIN );
		add_filter( 'plugin_action_links_'. $plugin, array( $this, 'add_settings_link' ) );

		add_action( 'admin_menu', array( $this, 'add_page' ) );
		add_action( 'admin_init', array( $this, 'init' ) );
	}

	///////////////////////////////////////
	/* 設定リンク追加 */
	///////////////////////////////////////
	public function add_settings_link( $links ) {
		$settings_link = '<a href="options-general.php?page=comment-report-setting">設定</a>';
		array_unshift( $links, $settings_link );
		return $links;
	}

	///////////////////////////////////////
	/* 設定ページ追加 */
	///////////////////////////////////////
	public function add_page() {
		add_options_page(
			'コメント通報ボタン', 
			'コメント通報ボタン', 
			'manage_options', 
			'comment-report-setting', 
			array( $this, 'setting' )
		);
	}

	///////////////////////////////////////
	/* 設定ページ */
	///////////////////////////////////////
	public function setting() {
		?>
		<div class="wrap">
			<?php // screen_icon(); ?>
			<h2>コメント通報ボタン設定</h2>
			<form method="post" action="options.php">
			<?php
				settings_fields( 'comment_report_setting' );   
				do_settings_sections( 'comment-report-setting' );
				submit_button(); 
			?>
			</form>
		</div>
		<?php
	}

	///////////////////////////////////////
	/* フィールド定義 */
	///////////////////////////////////////
	public function init() {
		$this->options = get_option( 'comment_report_option' );

		register_setting(
			'comment_report_setting',
			'comment_report_option',
			array( $this, 'sanitize' )
		);

		/* * */

		add_settings_section(
			'comment_report_section_base',
			'基本設定',
			false, // array( $this, 'print_section_info' ),
			'comment-report-setting'
		);

			add_settings_field(
				'auto_unauthorized',
				'自動非承認',
				array( $this, 'auto_unauthorized_callback' ),
				'comment-report-setting',
				'comment_report_section_base' 
			);

			add_settings_field(
				'auto_trash',
				'自動削除',
				array( $this, 'auto_trash_callback' ),
				'comment-report-setting',
				'comment_report_section_base' 
			);

			add_settings_field(
				'sendmail',
				'メール通知',
				array( $this, 'sendmail_callback' ),
				'comment-report-setting',
				'comment_report_section_base' 
			);

		/* * */

		add_settings_section(
			'comment_report_section_button',
			'ボタン設定',
			false,
			'comment-report-setting'
		);

			add_settings_field(
				'button_view',
				'ボタンの表示',
				array( $this, 'button_view_callback' ),
				'comment-report-setting',
				'comment_report_section_button' 
			);

			add_settings_field(
				'button_view_position',
				'ボタンの表示位置',
				array( $this, 'button_view_position_callback' ),
				'comment-report-setting',
				'comment_report_section_button' 
			);

			add_settings_field(
				'button_permission',
				'ボタンの押下可能権限',
				array( $this, 'button_permission_callback' ),
				'comment-report-setting',
				'comment_report_section_button' 
			);

		/* * */

		add_settings_section(
			'comment_report_section_design',
			'ボタンデザイン設定',
			array( $this, 'section_design' ),
			'comment-report-setting'
		);

			add_settings_field(
				'button_element',
				'ボタン要素',
				array( $this, 'button_element_callback' ),
				'comment-report-setting',
				'comment_report_section_design' 
			);

			add_settings_field(
				'button_text',
				'ボタンテキスト',
				array( $this, 'button_text_callback' ),
				'comment-report-setting',
				'comment_report_section_design' 
			);

			add_settings_field(
				'button_class', 
				'ボタンCSSクラス値', 
				array( $this, 'button_class_callback' ), 
				'comment-report-setting', 
				'comment_report_section_design'
			);	  

			add_settings_field(
				'button_style', 
				'ボタンCSS値', 
				array( $this, 'button_style_callback' ), 
				'comment-report-setting', 
				'comment_report_section_design'
			);	  
	}

	///////////////////////////////////////
	/* サニタイズ */
	///////////////////////////////////////
	public function sanitize( $input ) {
		$new_input = array();

		$absint = array(
			'auto_unauthorized',
			'auto_unauthorized_count',
			'auto_trash',
			'auto_trash_count',
			'sendmail',
			'sendmail_count',
		);

		$sanitize_text_field = array(
			'button_view',
			'button_view_position',
			'button_view_position_baf',
			'button_permission',
			'button_element',
			'button_text',
			'button_class',
			'button_style',
		);

		foreach ( $input as $key => $value) {
			if (in_array($key, $absint)) {
				$value = absint($value);
			}
			if (in_array($key, $sanitize_text_field)) {
				$value = sanitize_text_field($value);
			}
			$new_input[$key] = $value;
		}

		return $new_input;
	}

	///////////////////////////////////////
	/* ボタン設定説明 */
	///////////////////////////////////////
	public function section_design() {
		print '※ボタン出力時に設定を行った場合はそちらが優先されます';
	}

	///////////////////////////////////////
	/* 自動非承認 */
	///////////////////////////////////////
	public function auto_unauthorized_callback() {
		printf(
			'<label><input type="checkbox" name="comment_report_option[auto_unauthorized]" value="1"%s />通報数が'.
				'<input type="number" id="auto_unauthorized" name="comment_report_option[auto_unauthorized_count]" value="%s" class="small-text" />回を超えたら自動的にコメントを非承認にする</label>',
			checked( $this->options['auto_unauthorized'], 1, false ),
			isset( $this->options['auto_unauthorized_count'] ) ? esc_attr( $this->options['auto_unauthorized_count']) : ''
		);
	}

	///////////////////////////////////////
	/* 自動削除 */
	///////////////////////////////////////
	public function auto_trash_callback() {
		printf(
			'<label><input type="checkbox" name="comment_report_option[auto_trash]" value="1"%s />通報数が'.
				'<input type="number" id="auto_trash" name="comment_report_option[auto_trash_count]" value="%s" class="small-text" />回に超えたら自動的にコメントをゴミ箱へ移動にする</label>',
			checked( $this->options['auto_trash'], 1, false ),
			isset( $this->options['auto_trash_count'] ) ? esc_attr( $this->options['auto_trash_count']) : ''
		);
	}

	///////////////////////////////////////
	/* 自動削除 */
	///////////////////////////////////////
	public function sendmail_callback() {
		printf(
			'<label><input type="checkbox" name="comment_report_option[sendmail]" value="1"%s />通報数が'.
				'<input type="number" id="sendmail_count" name="comment_report_option[sendmail_count]" value="%s" class="small-text" />回を達したら'.
				'<input type="text" id="sendmail_address" name="comment_report_option[sendmail_address]" value="%s" />宛てにメールを送る</label>',
			checked( $this->options['sendmail'], 1, false ),
			isset( $this->options['sendmail_count'] ) ? esc_attr( $this->options['sendmail_count']) : '',
			isset( $this->options['sendmail_address'] ) ? esc_attr( $this->options['sendmail_address']) : ''
		);
	}

	///////////////////////////////////////
	/* ボタンの表示 */
	///////////////////////////////////////
	public function button_view_callback() {
		printf(
			'<label><input type="checkbox" name="comment_report_option[button_view]" value="1"%s />通報ボタンを表示する</label>',
			checked( $this->options['button_view'], 1, false )
		);
	}

	///////////////////////////////////////
	/* ボタン表示位置 */
	///////////////////////////////////////
	public function button_view_position_callback() {
		printf(
			'<select name="comment_report_option[button_view_position]">'.
				'<option value="auther"%s>コメント投稿者名</option>'.
				'<option value="date"%s>コメント投稿日</option>'.
				'<option value="time"%s>コメント投稿時刻</option>'.
				'<option value="edit"%s>コメント編集リンク</option>'.
				'<option value="reply"%s>コメント返信リンク</option>'.
				'<option value="text"%s>コメント文</option>'.
			'</select>',
			selected( $this->options['button_view_position'], 'auther', false ),
			selected( $this->options['button_view_position'], 'date', false ),
			selected( $this->options['button_view_position'], 'time', false ),
			selected( $this->options['button_view_position'], 'edit', false ),
			selected( $this->options['button_view_position'], 'reply', false ),
			selected( $this->options['button_view_position'], 'text', false )
		);
		printf(
			'<select name="comment_report_option[button_view_position_baf]">'.
				'<option value="before"%s>の前</option>'.
				'<option value="after"%s>の後</option>'.
			'</select>',
			selected( $this->options['button_view_position_baf'], 'before', false ),
			selected( $this->options['button_view_position_baf'], 'after', false )
		);
		echo
		'<br>テーマテンプレートの仕様次第では表示が崩れるので注意してください。<br>'.
		'直接テンプレート内から指定するにはテンプレートタグとして<code>comment_report_button()</code>を使用してください。';
	}

	///////////////////////////////////////
	/* ボタン押下可能権限 */
	///////////////////////////////////////
	public function button_permission_callback() {
		printf(
			'<select name="comment_report_option[button_permission]">'.
				'<option value="">なし</option>'.
				'<option value="level_0"%s>購読者</option>'.
				'<option value="level_1"%s>寄稿者</option>'.
				'<option value="level_2"%s>投稿者</option>'.
				'<option value="level_7"%s>編集者</option>'.
				'<option value="level_10"%s>管理者</option>'.
			'</select>',
			selected( $this->options['button_permission'], 'level_0', false ),
			selected( $this->options['button_permission'], 'level_1', false ),
			selected( $this->options['button_permission'], 'level_2', false ),
			selected( $this->options['button_permission'], 'level_7', false ),
			selected( $this->options['button_permission'], 'level_10', false )
		);
	}

	///////////////////////////////////////
	/* 通報ボタン要素 */
	///////////////////////////////////////
	public function button_element_callback() {
		printf(
			'<select name="comment_report_option[button_element]">'.
				'<option value="button"%s>&lt;button&gt;</option>'.
				'<option value="a"%s>&lt;a&gt;</option>'.
			'</select>',
			selected( $this->options['button_element'], 'button', false ),
			selected( $this->options['button_element'], 'a', false )
		);
	}

	///////////////////////////////////////
	/* 通報ボタンテキスト */
	///////////////////////////////////////
	public function button_text_callback() {
		printf(
			'<input type="text" id="button_text" name="comment_report_option[button_text]" value="%s" />',
			isset( $this->options['button_text'] ) ? esc_attr( $this->options['button_text']) : ''
		);
	}

	///////////////////////////////////////
	/* 通報ボタンCSSクラス */
	///////////////////////////////////////
	public function button_class_callback() {
		printf(
			'<input type="text" id="button_class" name="comment_report_option[button_class]" value="%s" />',
			isset( $this->options['button_class'] ) ? esc_attr( $this->options['button_class']) : ''
		);
	}

	///////////////////////////////////////
	/* 通報ボタンCSS値 */
	///////////////////////////////////////
	public function button_style_callback() {
		printf(
			'<input type="text" id="button_style" name="comment_report_option[button_style]" value="%s" class="regular-text" />',
			isset( $this->options['button_style'] ) ? esc_attr( $this->options['button_style']) : ''
		);
	}
}
